==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/mn-MN/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Энэ имэйл хаягтай байна.',
    'account_not_found'      => 'Хэрэглэгчийн нэр эсвэл нууц үг буруу байна.',
    'account_not_activated'  => 'Энэ хэрэглэгчийн бүртгэл идэвхжээгүй байна.',
    'account_suspended'      => 'Энэ хэрэглэгчийн бүртгэлийг түдгэлзүүлсэн байна.',
    'account_banned'         => 'Энэ хэрэглэгчийн бүртгэлийг хориглосон байна.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Та амжилттай нэвтэрсэн байна.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'Нэвтрэхийг оролдож байх явцад асуудал гарсан, дахин оролдоно уу.',
        'success' => 'Та амжилттай нэвтэрсэн байна.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Таны акаунтыг үүсгэх үед алдаа гарлаа, дахин оролдоно уу.',
        'success' => 'Акаунт амжилттай хийгдсэн.',
    ),

    'forgot-password' => array(
        'error'   => 'Нууц үгийг дахин тохируулахыг оролдож байх явцад асуудал гарлаа, дахин оролдоно уу.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Нууц үгээ шинэчлэхдээ алдаа гарлаа, дахин оролдоно уу.',
        'success' => 'Таны нууц үг амжилттай хийгдсэн.',
    ),


);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/mn-MN/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Энэ имэйл хаягтай байна.',
    'account_not_found'      => 'Хэрэглэгчийн нэр эсвэл нууц үг буруу байна.',
    'account_not_activated'  => 'Энэ хэрэглэгчийн бүртгэл идэвхжээгүй байна.',
    'account_suspended'      => 'Энэ хэрэглэгчийн бүртгэлийг түдгэлзүүлсэн байна.',
    'account_banned'         => 'Энэ хэрэглэгчийн бүртгэлийг хориглосон байна.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Та амжилттай нэвтэрсэн байна.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'Нэвтрэхийг оролдож байх явцад асуудал гарсан, дахин оролдоно уу.',
        'success' => 'Та амжилттай нэвтэрсэн байна.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Таны акаунтыг үүсгэх үед алдаа гарлаа, дахин оролдоно уу.',
        'success' => 'Акаунт амжилттай хийгдсэн.',
    ),

    'forgot-password' => array(
        'error'   => 'Нууц үгийг дахин тохируулахыг оролдож байх явцад асуудал гарлаа, дахин оролдоно уу.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Нууц үгээ шинэчлэхдээ алдаа гарлаа, дахин оролдоно уу.',
        'success' => 'Таны нууц үг амжилттай хийгдсэн.',
    ),


);
